<?php
/**
 * @file
 * Provides the admin interface and the output pane.
 */

/**
 * Plugins are described by creating a $plugin array which will be used
 * by the system that includes this file.
 */
$plugin = array(
  'title' => t('Promo node'),
  'single' => TRUE,
  'category' => array(t('Widgets')),
  'edit form' => 'promo_node_content_type_edit_form',
  'render callback' => 'promo_node_pane_content_type_render',
  'defaults' => array(
    'override_title' => FALSE,
    'override_title_text' => '',
    'widget' => '',
  ),
  'cache' => TRUE,
  'admin title' => 'promo_node_pane_content_type_admin_title',
  'admin info' => 'promo_node_pane_content_type_admin_info',
  'required context' => new ctools_context_optional(t('Context'), 'any'),
  'css' => array(drupal_get_path('module', 'promo_node') . '/plugins/content_types/css/promo_node_pane.css'),
);

/**
 * Implements hook_admin_info().
 *
 * Callback to provide administrative info.
 *
 * In this case just information the listing.
 *
 * @param array $subtype
 *   The subtype
 * @param array $conf
 *   The configuration
 * @param array $context
 *   The context that are used
 *
 * @return object
 *   A block that contains the output
 */
function promo_node_pane_content_type_admin_info($subtype, $conf, $context = NULL) {
  $block = promo_node_pane_content_type_render($subtype, $conf, $args = NULL, $context);
  return $block;
}

/**
 * Implements hook_admin_title().
 *
 * Callback to provide administrative titel
 *
 * @param array $subtype
 *   The subtype
 * @param array $conf
 *   The configuration
 * @param array $context
 *   Chosen context, if any
 *
 * @return object
 *   A block that contains the output
 */
function promo_node_pane_content_type_admin_title($subtype, $conf, $context = NULL) {
  $output = t('Promo node');
  if ($conf['override_title'] && !empty($conf['override_title_text'])) {
    $output = filter_xss_admin($conf['override_title_text']);
  }
  return $output;
}


/**
 * Implements hook_content_type_render().
 *
 * @param array $subtype
 *   The subtype
 * @param array $conf
 *   The configuration
 * @param array $args
 *   Arguments
 * @param array $context
 *   Choosen context, if any.
 *
 * @return object
 *   A block that contains the output
 */
function promo_node_pane_content_type_render($subtype, $conf, $args, $context) {
  $block = new stdClass();
  $block->title = t("Promo node");
  $block->content = _promo_node_display_output($conf['promo_node_kicker'], $conf['promo_node_heading'], $conf['promo_node_teaser'], $conf['promo_node_url'], $conf['promo_node_url_description'], $context);
  return $block;
}

/**
 * The configuration form.
 *
 * @param array $form
 *   The form used for configuration.
 * @param array &$form_state
 *   Form state of the form.
 *
 * @return object
 *   The complete configuration form.
 */
function promo_node_content_type_edit_form($form, &$form_state) {

  $css = file_get_contents(drupal_get_path('module', 'promo_node') . '/plugins/content_types/css/promo_node_pane.css');
  $form['css'] = array(
    '#markup' => '<style type="text/css">' . $css . '</style>',
  );

  $conf = $form_state['conf'];

  if (module_exists('token') == TRUE) {
    $form['info'] = array(
      '#markup' => t('<p>You could use <strong>node</strong> tokens, like
        <em>[node:title]</em> and <em>[node:summary]<em> for url description, kicker, headline
        and teaser</p><p>See, !token_help for available tokens</p>',
        array(
          '!token_help' => l(t('Token help page'), "admin/help/token",
        array(
          'attributes' => array('target' => '_blank'))))),
    );
  }
  else {
    $form['info'] = array(
      '#markup' => '<p>If you enable the token module you could use tokens in kicker, headline and teaser fields</p>',
    );
  }

  $form['promo_node_url'] = array(
    '#type' => 'textfield',
    '#required' => TRUE,
    '#title' => t('Node'),
    '#size' => 85,
    '#autocomplete_path' => 'ctools/autocomplete/node',
    '#default_value' => !empty($conf['promo_node_url']) ? $conf['promo_node_url'] : '',
  );
  $form['promo_node_url_description'] = array(
    '#type' => 'textfield',
    '#required' => FALSE,
    '#title' => t('URL description'),
    '#size' => 40,
    '#description' => t('A URL description for the referenced node.'),
    '#default_value' => !empty($conf['promo_node_url_description']) ? $conf['promo_node_url_description'] : '',
  );
  $form['promo_node_kicker'] = array(
    '#type' => 'textfield',
    '#required' => FALSE,
    '#title' => t('Kicker'),
    '#size' => 40,
    '#description' => t('Kicker to use for node promo, if any.'),
    '#default_value' => !empty($conf['promo_node_kicker']) ? $conf['promo_node_kicker'] : '',
  );
  $form['promo_node_heading'] = array(
    '#type' => 'textfield',
    '#required' => FALSE,
    '#title' => t('Heading'),
    '#size' => 40,
    '#description' => t('Heading to use for the node promo, if any'),
    '#default_value' => !empty($conf['promo_node_heading']) ? $conf['promo_node_heading'] : '',
  );
  $form['promo_node_teaser'] = array(
    '#type' => 'textarea',
    '#required' => FALSE,
    '#title' => t('Teaser'),
    '#rows' => 3,
    '#cols' => 10,
    '#description' => t('Teaser to use for node promo, if any.'),
    '#default_value' => !empty($conf['promo_node_teaser']) ? $conf['promo_node_teaser'] : '',
  );
  return $form;
}

/**
 * Saves the configuration.
 *
 * @param array &$form
 *   The form that are beeing used.
 * @param array &$form_state
 *   Form states in the form.
 *
 * @return array
 *   Settings to store
 */
function promo_node_content_type_edit_form_submit(&$form, &$form_state) {
  foreach (element_children($form) as $key) {
    $form_state['conf'][$key] = $form_state['values'][$key];
  }
}

/**
 * Outputs the list with the configuration.
 *
 * @param string $kicker
 *   Kicker value.
 * @param string $heading
 *   Heading value.
 * @param string $teaser
 *   Teaser value.
 * @param array $context
 *   Chosen context, if any.
 *
 * @return object
 *   The list that are configured.
 */
function _promo_node_display_output($kicker, $heading, $teaser, $node_url, $node_url_description, $context) {
  if (isset($node_url)) {
    $match_nid = preg_match('/\[id: (\d+)\]/', $node_url, $preg_match_nid);
    if (isset($preg_match_nid)) {
      $node_id = $preg_match_nid[1];
      $url = '/' . (drupal_get_path_alias('node/' . $node_id));
    }
    if (!isset($url)) {
      $url = 'node/' . $node_id;
    }
  }
  // Token support in teaser field for node.
  if (isset($node_id)) {
    $node = node_load($node_id);
    $data = array('node' => $node);
    $kicker = token_replace($kicker, $data);
    $heading = token_replace($heading, $data);
    $teaser = token_replace($teaser, $data);
    $node_url_description = token_replace($node_url_description, $data);
  }
  $output = theme('promo_output', array(
    'kicker' => check_plain($kicker),
    'heading' => check_plain($heading),
    'teaser' => check_markup($teaser),
    'node_url' =>  check_plain($url),
    'node_url_description' => check_plain($node_url_description),
    ));
  return $output;
}
